pub struct BackupConfiguration {
pub backup_retention_settings: Option<BackupRetentionSettings>,
pub backup_tier: Option<String>,
pub binary_log_enabled: Option<bool>,
pub enabled: Option<bool>,
pub kind: Option<String>,
pub location: Option<String>,
pub point_in_time_recovery_enabled: Option<bool>,
pub replication_log_archiving_enabled: Option<bool>,
pub start_time: Option<String>,
pub transaction_log_retention_days: Option<i32>,
pub transactional_log_storage_state: Option<String>,
}Expand description
Database instance backup configuration.
This type is not used in any activity, and only used as part of another schema.
Fields
backup_retention_settings: Option<BackupRetentionSettings>Backup retention settings.
backup_tier: Option<String>Output only. Backup tier that manages the backups for the instance.
binary_log_enabled: Option<bool>(MySQL only) Whether binary log is enabled. If backup configuration is disabled, binarylog must be disabled as well.
enabled: Option<bool>Whether this configuration is enabled.
kind: Option<String>This is always sql#backupConfiguration.
location: Option<String>Location of the backup
point_in_time_recovery_enabled: Option<bool>Whether point in time recovery is enabled.
replication_log_archiving_enabled: Option<bool>Reserved for future use.
start_time: Option<String>Start time for the daily backup configuration in UTC timezone in the 24 hour format - HH:MM.
transaction_log_retention_days: Option<i32>The number of days of transaction logs we retain for point in time restore, from 1-7.
transactional_log_storage_state: Option<String>Output only. This value contains the storage location of transactional logs used to perform point-in-time recovery (PITR) for the database.