pub struct ConnectPoolNodeConfig {
pub dns_name: Option<String>,
pub dns_names: Option<Vec<DnsNameMapping>>,
pub ip_addresses: Option<Vec<IpMapping>>,
pub name: Option<String>,
}Expand description
Details of a single read pool node of a read pool.
This type is not used in any activity, and only used as part of another schema.
Fields
dns_name: Option<String>Output only. The DNS name of the read pool node.
dns_names: Option<Vec<DnsNameMapping>>Output only. The list of DNS names used by this read pool node.
ip_addresses: Option<Vec<IpMapping>>Output only. Mappings containing IP addresses that can be used to connect to the read pool node.
name: Option<String>Output only. The name of the read pool node. Doesn’t include the project ID.