ConnectionPoolFlags

Struct ConnectionPoolFlags 

pub struct ConnectionPoolFlags {
    pub name: Option<String>,
    pub value: Option<String>,
}
Connection pool flags for Cloud SQL instances managed connection pool configuration.

This type is not used in any activity, and only used as part of another schema.

Fields

name: Option<String>

Required. The name of the flag.

value: Option<String>

Required. The value of the flag. Boolean flags are set to on for true and off for false. This field must be omitted if the flag doesn’t take a value.