pub struct ExportContext {
pub bak_export_options: Option<ExportContextBakExportOptions>,
pub csv_export_options: Option<ExportContextCsvExportOptions>,
pub databases: Option<Vec<String>>,
pub file_type: Option<String>,
pub kind: Option<String>,
pub offload: Option<bool>,
pub sql_export_options: Option<ExportContextSqlExportOptions>,
pub tde_export_options: Option<ExportContextTdeExportOptions>,
pub uri: Option<String>,
}Expand description
Database instance export context.
This type is not used in any activity, and only used as part of another schema.
Fields
bak_export_options: Option<ExportContextBakExportOptions>Options for exporting BAK files (SQL Server-only)
csv_export_options: Option<ExportContextCsvExportOptions>Options for exporting data as CSV. MySQL and PostgreSQL instances only.
databases: Option<Vec<String>>Databases to be exported. MySQL instances: If fileType is SQL and no database is specified, all databases are exported, except for the mysql system database. If fileType is CSV, you can specify one database, either by using this property or by using the csvExportOptions.selectQuery property, which takes precedence over this property. PostgreSQL instances: If you don’t specify a database by name, all user databases in the instance are exported. This excludes system databases and Cloud SQL databases used to manage internal operations. Exporting all user databases is only available for directory-formatted parallel export. If fileType is CSV, this database must match the one specified in the csvExportOptions.selectQuery property. SQL Server instances: You must specify one database to be exported, and the fileType must be BAK.
file_type: Option<String>The file type for the specified uri.
kind: Option<String>This is always sql#exportContext.
offload: Option<bool>Whether to perform a serverless export.
sql_export_options: Option<ExportContextSqlExportOptions>Options for exporting data as SQL statements.
tde_export_options: Option<ExportContextTdeExportOptions>Optional. Export parameters specific to SQL Server TDE certificates
uri: Option<String>The path to the file in Google Cloud Storage where the export will be stored. The URI is in the form gs://bucketName/fileName. If the file already exists, the request succeeds, but the operation fails. If fileType is SQL and the filename ends with .gz, the contents are compressed.