pub struct ImportContextSqlImportOptionsPostgresImportOptions {
pub clean: Option<bool>,
pub if_exists: Option<bool>,
}Expand description
Optional. Options for importing from a Cloud SQL for PostgreSQL instance.
This type is not used in any activity, and only used as part of another schema.
Fields
clean: Option<bool>Optional. The –clean flag for the pg_restore utility. This flag applies only if you enabled Cloud SQL to import files in parallel.
if_exists: Option<bool>Optional. The –if-exists flag for the pg_restore utility. This flag applies only if you enabled Cloud SQL to import files in parallel.