pub struct ListBackupsResponse {
pub backups: Option<Vec<Backup>>,
pub next_page_token: Option<String>,
pub warnings: Option<Vec<ApiWarning>>,
}Expand description
The response payload containing a list of the backups.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list backups backups (response)
Fields
backups: Option<Vec<Backup>>A list of backups.
next_page_token: Option<String>A token, which can be sent as page_token to retrieve the next page. If this field is omitted, then there aren’t subsequent pages.
warnings: Option<Vec<ApiWarning>>If a region isn’t unavailable or if an unknown error occurs, then a warning message is returned.