pub struct Message {
pub message: Option<String>,
pub severity: Option<String>,
}Expand description
Represents a notice or warning message from the database.
This type is not used in any activity, and only used as part of another schema.
Fields
message: Option<String>The full message string. For PostgreSQL, this is a formatted string that may include severity, code, and the notice/warning message. For MySQL, this contains the warning message.
severity: Option<String>The severity of the message (e.g., “NOTICE” for PostgreSQL, “WARNING” for MySQL).