pub struct Metadata {
pub sql_statement_execution_time: Option<Duration>,
}Expand description
The additional metadata information regarding the execution of the SQL statements.
This type is not used in any activity, and only used as part of another schema.
Fields
sql_statement_execution_time: Option<Duration>The time taken to execute the SQL statements.