pub struct PerformanceCaptureConfig {
pub enabled: Option<bool>,
pub probe_threshold: Option<i32>,
pub probing_interval_seconds: Option<i32>,
pub running_threads_threshold: Option<i32>,
pub seconds_behind_source_threshold: Option<i32>,
pub transaction_duration_threshold: Option<i32>,
}Expand description
Performance Capture configuration.
This type is not used in any activity, and only used as part of another schema.
Fields
enabled: Option<bool>Optional. Enable or disable the Performance Capture feature.
probe_threshold: Option<i32>Optional. The minimum number of consecutive readings above threshold that triggers instance state capture.
probing_interval_seconds: Option<i32>Optional. The time interval in seconds between any two probes.
running_threads_threshold: Option<i32>Optional. The minimum number of server threads running to trigger the capture on primary.
seconds_behind_source_threshold: Option<i32>Optional. The minimum number of seconds replica must be lagging behind primary to trigger capture on replica.
transaction_duration_threshold: Option<i32>Optional. The amount of time in seconds that a transaction needs to have been open before the watcher starts recording it.