pub struct PoolNodeConfig {
pub dns_name: Option<String>,
pub dns_names: Option<Vec<DnsNameMapping>>,
pub gce_zone: Option<String>,
pub ip_addresses: Option<Vec<IpMapping>>,
pub name: Option<String>,
pub psc_auto_connections: Option<Vec<PscAutoConnectionConfig>>,
pub psc_service_attachment_link: Option<String>,
pub state: Option<String>,
}Expand description
Details of a single read pool node of a read pool.
This type is not used in any activity, and only used as part of another schema.
Fields
dns_name: Option<String>Output only. The DNS name of the read pool node.
dns_names: Option<Vec<DnsNameMapping>>Output only. The list of DNS names used by this read pool node.
gce_zone: Option<String>Output only. The zone of the read pool node.
ip_addresses: Option<Vec<IpMapping>>Output only. Mappings containing IP addresses that can be used to connect to the read pool node.
name: Option<String>Output only. The name of the read pool node, to be used for retrieving metrics and logs.
psc_auto_connections: Option<Vec<PscAutoConnectionConfig>>Output only. The list of settings for requested automatically-setup Private Service Connect (PSC) consumer endpoints that can be used to connect to this read pool node.
psc_service_attachment_link: Option<String>Output only. The Private Service Connect (PSC) service attachment of the read pool node.
state: Option<String>Output only. The current state of the read pool node.