pub struct PreCheckResponse {
pub actions_required: Option<Vec<String>>,
pub message: Option<String>,
pub message_type: Option<String>,
}Expand description
Structured PreCheckResponse containing message, type, and required actions.
This type is not used in any activity, and only used as part of another schema.
Fields
actions_required: Option<Vec<String>>The actions that the user needs to take. Use repeated for multiple actions.
message: Option<String>The message to be displayed to the user.
message_type: Option<String>The type of message whether it is an info, warning, or error.