pub struct PscAutoConnectionConfig {
pub consumer_network: Option<String>,
pub consumer_network_status: Option<String>,
pub consumer_project: Option<String>,
pub ip_address: Option<String>,
pub status: Option<String>,
}Expand description
Settings for an automatically-setup Private Service Connect consumer endpoint that is used to connect to a Cloud SQL instance.
This type is not used in any activity, and only used as part of another schema.
Fields
consumer_network: Option<String>Optional. The consumer network of this consumer endpoint. This must be a resource path that includes both the host project and the network name. For example, projects/project1/global/networks/network1. The consumer host project of this network might be different from the consumer service project.
consumer_network_status: Option<String>The connection policy status of the consumer network.
consumer_project: Option<String>Optional. This is the project ID of consumer service project of this consumer endpoint. Optional. This is only applicable if consumer_network is a shared vpc network.
ip_address: Option<String>The IP address of the consumer endpoint.
status: Option<String>The connection status of the consumer endpoint.