pub struct QueryResult {
pub columns: Option<Vec<Column>>,
pub message: Option<String>,
pub partial_result: Option<bool>,
pub rows: Option<Vec<Row>>,
pub status: Option<Status>,
}Expand description
QueryResult contains the result of executing a single SQL statement.
This type is not used in any activity, and only used as part of another schema.
Fields
columns: Option<Vec<Column>>List of columns included in the result. This also includes the data type of the column.
message: Option<String>Message related to the SQL execution result.
partial_result: Option<bool>Set to true if the SQL execution’s result is truncated due to size limits or an error retrieving results.
rows: Option<Vec<Row>>Rows returned by the SQL statement.
status: Option<Status>If results were truncated due to an error, details of that error.