pub struct ReadPoolAutoScaleConfig {
pub disable_scale_in: Option<bool>,
pub enabled: Option<bool>,
pub max_node_count: Option<i32>,
pub min_node_count: Option<i32>,
pub scale_in_cooldown_seconds: Option<i32>,
pub scale_out_cooldown_seconds: Option<i32>,
pub target_metrics: Option<Vec<TargetMetric>>,
}Expand description
The read pool auto-scale configuration.
This type is not used in any activity, and only used as part of another schema.
Fields
disable_scale_in: Option<bool>Indicates whether read pool auto scaling supports scale in operations (removing nodes).
enabled: Option<bool>Indicates whether read pool auto scaling is enabled.
max_node_count: Option<i32>Maximum number of read pool nodes to be maintained.
min_node_count: Option<i32>Minimum number of read pool nodes to be maintained.
scale_in_cooldown_seconds: Option<i32>The cooldown period for scale-in operations.
scale_out_cooldown_seconds: Option<i32>The cooldown period for scale-out operations.
target_metrics: Option<Vec<TargetMetric>>Optional. Target metrics for read pool auto scaling.