ReplicationCluster

Struct ReplicationCluster 

pub struct ReplicationCluster {
    pub dr_replica: Option<bool>,
    pub failover_dr_replica_name: Option<String>,
    pub psa_write_endpoint: Option<String>,
}
A primary instance and disaster recovery (DR) replica pair. A DR replica is a cross-region replica that you designate for failover in the event that the primary instance experiences regional failure. Applicable to MySQL and PostgreSQL.

This type is not used in any activity, and only used as part of another schema.

Fields

dr_replica: Option<bool>

Output only. Read-only field that indicates whether the replica is a DR replica. This field is not set if the instance is a primary instance.

failover_dr_replica_name: Option<String>

Optional. If the instance is a primary instance, then this field identifies the disaster recovery (DR) replica. A DR replica is an optional configuration for Enterprise Plus edition instances. If the instance is a read replica, then the field is not set. Set this field to a replica name to designate a DR replica for a primary instance. Remove the replica name to remove the DR replica designation.

psa_write_endpoint: Option<String>

Output only. If set, this field indicates this instance has a private service access (PSA) DNS endpoint that is pointing to the primary instance of the cluster. If this instance is the primary, then the DNS endpoint points to this instance. After a switchover or replica failover operation, this DNS endpoint points to the promoted instance. This is a read-only field, returned to the user as information. This field can exist even if a standalone instance doesn’t have a DR replica yet or the DR replica is deleted.